@@ -1,6 +1,6 @@
 import enum
 import inspect
-import collections
+import collections.abc
 
 import typing
 import types
@@ -280,7 +280,7 @@ class GraphQLTypeMapper:
 
             for arg, mapped_type in union_map.items():
                 if issubclass(value_type, arg):
-                    return mapped_type
+                    return mapped_type.name
 
         names = [arg.__name__ for arg in union_args]
         name = f"{''.join(names)}{self.suffix}Union"
@@ -314,7 +314,7 @@ class GraphQLTypeMapper:
         enum_type.enum_type = type_
 
         def serialize(self, value) -> Union[str, None, UndefinedType]:
-            if value and isinstance(value, collections.Hashable):
+            if value and isinstance(value, collections.abc.Hashable):
                 if isinstance(value, enum.Enum):
                     value = value.value
 
@@ -372,7 +372,7 @@ class GraphQLTypeMapper:
             local_self = self
 
             def resolve_type(value, info, _type):
-                return local_self.map(type(value))
+                return local_self.map(type(value)).name
             return resolve_type
 
         def local_fields():
